![Screenshot](votingLNC.png)

# votingLNC: LncRNA identification through majority voting ensemble learning

<!-- badges: start -->
<!-- badges: end -->

This repository describes the votingLNC tool based on the majority voting principle which was used to identify lncRNA transcripts in LncPlankton V1.0 database.
The package contains a set of R functions to reliably predict lncRNAs. The package provides functions to post-process the output results coming from each coding potential prediction tool included in the ensemle.


## Description
We combined the results of ten coding potential prediction classifiers: CPC2 ,CPAT, LGC, LncADeep, LncDC, lncFinder, longdist, mRNN, RNAmining, and RNASamba; into a single meta-learner in a majority-voting setting called votingLNC.
The aim is to increase the reliability and to promote the diversity of the ensemble model by combining all the predictions from 10 classification models. Each tool used a different algorithm and different training features, and may 
produce a different classification result. Aggregating those different techniques in a majority setting led to a single prediction representing the group’s consensus. We believe that such a hybrid technique leads to more reliable 
results and acceptable performance. Briefly, each transcript was predicted by each classifier and labelled as “Coding” or “Noncoding”, and the class with the highest number of votes was the outcome. Several filters were applied on 
the “Noncoding” set to discriminate between lncRNAs and sncRNAs.


## Prerequisites
- Please provide the python packages and the conda environment (including the python version) mandatory to launch the prediction using votingLNC. The following should be installed:
	[ezLncPred](https://github.com/LittleHannah/ezLncPred): which is a wrapper for CPC2, CPAT, LGC and longdist,
	[LncADeep](https://github.com/cyang235/LncADeep): LncADeep: An ab initio lncRNA identification and functional annotation tool based on deep learning
	[LncDC](https://github.com/lim74/LncDC): LncDC: a machine learning-based tool for long non-coding RNA detection from RNA-Seq data
	[mRNN](https://github.com/hendrixlab/mRNN): LncDC: a machine learning-based tool for long non-coding RNA detection from RNA-Seq data
	[RNAmining](https://gitlab.com/integrativebioinformatics/RNAmining): RNAmining: A machine learning stand-alone and web server tool for RNA coding potential prediction
	[RNASamba](https://github.com/apcamargo/RNAsamba): RNASamba: neural network-based assessment of the protein-coding potential of RNA sequences
	
- Please adapt the content of the config.ini file: this file contains all the paths to the binary and executable files of the 10 coding potential tools included in our meta-tool and their own python environment.
- The following R packages should be installed before launching the package: cowsay, pbapply, dplyr, ggplot2, ggrepel, gridExtra, wesanderson, configr,
  LncFinder, seqinr, ftrCOOL, micropan, stringr, magrittr, keras
	
	
## Install 

To use this tool on local machine, simply download the package from gitlab: https://gitlab.com/a.debit/votingLNC as a tarball
or from lncPlankton V1.0 website as follows:

```
wget https://www.lncplankton.bio.ens.psl.eu/files/tools/votingLNC.tar.gz
```
And then install the tool

```
install.packages("votingLNC.tar.gz", type"source", repos=NULL)
```
Or by using install_gitlab

```
install.packages("remotes")
remotes::install_gitlab("a.debit/votingLNC")
```
## Running the predict

For the test, we used the Arabidopsis thaliana dataset published in the data_test folder

```
# load the library into the R environment 
>library(votingLNC)

>votingLNC(pathFolder="./data_test", prob=0.5, tr.len=200, pep.len=100)

..............Summary .....................
...........................................
...........................................
Parameters:
Probability threshold: 0.8
Transcript length: 200
Peptide length: 200

Results:
-------ncRNAs: 5707(50.47%)
-------------lncRNA-like: 3762(33.27%)
-------------sncRNA-like: 1221(10.80%)
-------Coding: 5600(49.53%)

>head(df.majority)

			   transcript_length peptide_length maj.class probability Majority_Class
AT1G05853.1               101              0         1        1.00    sncRNA-like
AT2G04455.1               195             14         1        1.00    sncRNA-like
AT5G09945.1               195             49         1        1.00    sncRNA-like
AT4G04185.1               101              3         1        0.78    Coding-like
AT4G06405.1                55              0         1        1.00    sncRNA-like
AT3G08735.1               194              6         1        1.00    sncRNA-like
...
...
```



# Publication

Debit, A., Vincens, P., Bowler, C. and Cruz de Carvalho, H., 2023. LncPlankton V1. 0: a comprehensive collection of plankton long non-coding RNAs. bioRxiv, pp.2023-11.

# Authors

* **Ahmed Debit** - Post-Doc Bioinformatics IBENS Paris

# References
- Xu, X., Liu, S., Yang, Z., Zhao, X., Deng, Y., Zhang, G., Pang, J., Zhao, C. and Zhang, W., 2021. A systematic review of computational methods for predicting long noncoding RNAs. Briefings in functional genomics, 20(3), pp.162-173.
- Kang, Y.J., Yang, D.C., Kong, L., Hou, M., Meng, Y.Q., Wei, L. and Gao, G., 2017. CPC2: a fast and accurate coding potential calculator based on sequence intrinsic features. Nucleic acids research, 45(W1), pp.W12-W16.
- Wang, L., Park, H.J., Dasari, S., Wang, S., Kocher, J.P. and Li, W., 2013. CPAT: Coding-Potential Assessment Tool using an alignment-free logistic regression model. Nucleic acids research, 41(6), pp.e74-e74.
- Wang, G., Yin, H., Li, B., Yu, C., Wang, F., Xu, X., Cao, J., Bao, Y., Wang, L., Abbasi, A.A. and Bajic, V.B., 2019. Characterization and identification of long non-coding RNAs based on feature relationship. Bioinformatics, 35(17), pp.2949-2956.
- Schneider, H.W.; Raiol, T.; Brigido, M.M.; Walter, M.E.M.; Stadler, P.F. A support vector machine based method to distinguish long non-coding RNAs from protein coding transcripts.
- Han, S., Liang, Y., Ma, Q., Xu, Y., Zhang, Y., Du, W., Wang, C. and Li, Y., 2019. LncFinder: an integrated platform for long non-coding RNA identification utilizing sequence intrinsic composition, structural information and physicochemical property. Briefings in bioinformatics, 20(6), pp.2009-2027.
- Hill, S.T., Kuintzle, R., Teegarden, A., Merrill III, E., Danaee, P. and Hendrix, D.A., 2018. A deep recurrent neural network discovers complex biological rules to decipher RNA protein-coding potential. Nucleic acids research, 46(16), pp.8105-8113.
- Ramos, T.A., Galindo, N.R., Arias-Carrasco, R., da Silva, C.F., Maracaja-Coutinho, V. and do Rêgo, T.G., 2021. RNAmining: A machine learning stand-alone and web server tool for RNA coding potential prediction. F1000Research, 10.
- Camargo, A.P., Sourkov, V., Pereira, G.A.G. and Carazzolle, M.F., 2020. RNAsamba: neural network-based assessment of the protein-coding potential of RNA sequences. NAR genomics and bioinformatics, 2(1), p.lqz024.
- Li, M. and Liang, C., 2022. LncDC: A machine learning-based tool for long non-coding RNA detection from RNA-Seq data. Scientific Reports, 12(1), p.19083.




 